@@ -40,21 +40,21 @@
 #'
 #' @examples
 #' # add_labels()
-
 #' data(efc)
 #' get_labels(efc$e42dep)
 #'
 #' x <- add_labels(efc$e42dep, labels = c(`nothing` = 5))
 #' get_labels(x)
 #'
-#' library(dplyr)
-#' x <- efc %>%
-#'   # select three variables
-#'   dplyr::select(e42dep, c172code, c161sex) %>%
-#'   # only add new label to two of those
-#'   add_labels(e42dep, c172code, labels = c(`nothing` = 5))
-#' # see data frame, with selected variables having new labels
-#' get_labels(x)
+#' if (require("dplyr")) {
+#'   x <- efc %>%
+#'     # select three variables
+#'     dplyr::select(e42dep, c172code, c161sex) %>%
+#'     # only add new label to two of those
+#'     add_labels(e42dep, c172code, labels = c(`nothing` = 5))
+#'   # see data frame, with selected variables having new labels
+#'   get_labels(x)
+#' }
 #'
 #' x <- add_labels(efc$e42dep, labels = c(`nothing` = 5, `zero value` = 0))
 #' get_labels(x, values = "p")
@@ -67,15 +67,16 @@
 #' get_labels(x, values = "p")
 #'
 #' # replace specific missing value (tagged NA)
-#' library(haven)
-#' x <- labelled(c(1:3, tagged_na("a", "c", "z"), 4:1),
-#'               c("Agreement" = 1, "Disagreement" = 4, "First" = tagged_na("c"),
-#'                 "Refused" = tagged_na("a"), "Not home" = tagged_na("z")))
-#' # get current NA values
-#' x
-#' # tagged NA(c) has currently the value label "First", will be
-#' # replaced by "Second" now.
-#' replace_labels(x, labels = c("Second" = tagged_na("c")))
+#' if (require("haven")) {
+#'   x <- labelled(c(1:3, tagged_na("a", "c", "z"), 4:1),
+#'                 c("Agreement" = 1, "Disagreement" = 4, "First" = tagged_na("c"),
+#'                   "Refused" = tagged_na("a"), "Not home" = tagged_na("z")))
+#'   # get current NA values
+#'   x
+#'   # tagged NA(c) has currently the value label "First", will be
+#'   # replaced by "Second" now.
+#'   replace_labels(x, labels = c("Second" = tagged_na("c")))
+#' }
 #'
 #'
 #' # remove_labels()
@@ -86,15 +87,14 @@
 #' x <- remove_labels(efc$e42dep, labels = "independent")
 #' get_labels(x, values = "p")
 #'
-#' library(haven)
-#' x <- labelled(c(1:3, tagged_na("a", "c", "z"), 4:1),
-#'               c("Agreement" = 1, "Disagreement" = 4, "First" = tagged_na("c"),
-#'                 "Refused" = tagged_na("a"), "Not home" = tagged_na("z")))
-#' # get current NA values
-#' get_na(x)
-#' get_na(remove_labels(x, labels = tagged_na("c")))
-#'
-#' @importFrom rlang quos
+#' if (require("haven")) {
+#'   x <- labelled(c(1:3, tagged_na("a", "c", "z"), 4:1),
+#'                 c("Agreement" = 1, "Disagreement" = 4, "First" = tagged_na("c"),
+#'                   "Refused" = tagged_na("a"), "Not home" = tagged_na("z")))
+#'   # get current NA values
+#'   get_na(x)
+#'   get_na(remove_labels(x, labels = tagged_na("c")))
+#' }
 #' @export
 add_labels <- function(x, ..., labels) {
 
@@ -103,7 +103,8 @@ add_labels <- function(x, ..., labels) {
   if (is.null(names(labels))) stop("`labels` must be a named vector.", call. = F)
 
   # evaluate arguments, generate data
-  .dat <- get_dot_data(x, rlang::quos(...))
+  dots <- as.character(match.call(expand.dots = FALSE)$`...`)
+  .dat <- .get_dot_data(x, dots)
 
   if (is.data.frame(x)) {
     # iterate variables of data frame
@@ -117,7 +118,6 @@ add_labels <- function(x, ..., labels) {
   x
 }
 
-#' @importFrom haven is_tagged_na na_tag
 add_labels_helper <- function(x, value) {
   # get current labels of `x`
   current.labels <- get_labels(
@@ -156,26 +156,28 @@ add_labels_helper <- function(x, value) {
     all.labels <- value
   }
 
-  # replace tagged NA
-  if (any(haven::is_tagged_na(value))) {
-    # get tagged NAs
-    value_tag <- haven::na_tag(value)[haven::is_tagged_na(value)]
-    cna_tag <- haven::na_tag(current.na)
+  if (requireNamespace("haven", quietly = TRUE)) {
+    # replace tagged NA
+    if (any(haven::is_tagged_na(value))) {
+      # get tagged NAs
+      value_tag <- haven::na_tag(value)[haven::is_tagged_na(value)]
+      cna_tag <- haven::na_tag(current.na)
 
-    # find matches (replaced NA), i.e. see if 'x' has any
-    # tagged NA values that match the tagged NA specified in 'value'
-    doubles <- na.omit(match(value_tag, cna_tag))
+      # find matches (replaced NA), i.e. see if 'x' has any
+      # tagged NA values that match the tagged NA specified in 'value'
+      doubles <- na.omit(match(value_tag, cna_tag))
 
-    # tell user if we found any tagged NA, and that these will be replaced
-    if (any(doubles)) {
-      message(sprintf(
-        "tagged NA '%s' was replaced with new value label.\n",
-        names(current.na)[doubles]
-      ))
+      # tell user if we found any tagged NA, and that these will be replaced
+      if (any(doubles)) {
+        message(sprintf(
+          "tagged NA '%s' was replaced with new value label.\n",
+          names(current.na)[doubles]
+        ))
+      }
+
+      # remove multiple tagged NA
+      current.na <- current.na[-doubles]
     }
-
-    # remove multiple tagged NA
-    current.na <- current.na[-doubles]
   }
 
   # sort labels by values
