@@ -112,12 +112,11 @@
 #' get_labels(fill_labels(x))
 #' # same as
 #' get_labels(x, non.labelled = TRUE)
-#'
 #' @importFrom stats na.omit
 #' @export
 zap_labels <- function(x, ...) {
-  # evaluate arguments, generate data
-  .dat <- get_dot_data(x, rlang::quos(...))
+  dots <- as.character(match.call(expand.dots = FALSE)$`...`)
+  .dat <- .get_dot_data(x, dots)
 
   if (is.data.frame(x)) {
     # iterate variables of data frame
@@ -136,8 +135,8 @@ zap_labels <- function(x, ...) {
 #' @importFrom stats na.omit
 #' @export
 zap_unlabelled <- function(x, ...) {
-  # evaluate arguments, generate data
-  .dat <- get_dot_data(x, rlang::quos(...))
+  dots <- as.character(match.call(expand.dots = FALSE)$`...`)
+  .dat <- .get_dot_data(x, dots)
 
   if (is.data.frame(x)) {
     # iterate variables of data frame
@@ -166,28 +165,28 @@ zap_unlabelled <- function(x, ...) {
 #' @return \code{x}, where all \code{tagged_na} values are converted to \code{NA}.
 #'
 #' @examples
-#' library(haven)
-#' x <- labelled(
-#'   c(1:3, tagged_na("a", "c", "z"), 4:1),
-#'   c("Agreement" = 1, "Disagreement" = 4, "First" = tagged_na("c"),
-#'     "Refused" = tagged_na("a"), "Not home" = tagged_na("z"))
-#' )
-#' # get current NA values
-#' x
-#' get_na(x)
-#' zap_na_tags(x)
-#' get_na(zap_na_tags(x))
-#'
-#' # also works with non-labelled vector that have tagged NA values
-#' x <- c(1:5, tagged_na("a"), tagged_na("z"), NA)
-#' haven::print_tagged_na(x)
-#' haven::print_tagged_na(zap_na_tags(x))
+#' if (require("haven")) {
+#'   x <- labelled(
+#'     c(1:3, tagged_na("a", "c", "z"), 4:1),
+#'     c("Agreement" = 1, "Disagreement" = 4, "First" = tagged_na("c"),
+#'       "Refused" = tagged_na("a"), "Not home" = tagged_na("z"))
+#'   )
+#'   # get current NA values
+#'   x
+#'   get_na(x)
+#'   zap_na_tags(x)
+#'   get_na(zap_na_tags(x))
 #'
+#'   # also works with non-labelled vector that have tagged NA values
+#'   x <- c(1:5, tagged_na("a"), tagged_na("z"), NA)
+#'   haven::print_tagged_na(x)
+#'   haven::print_tagged_na(zap_na_tags(x))
+#' }
 #' @importFrom stats na.omit
 #' @export
 zap_na_tags <- function(x, ...) {
-  # evaluate arguments, generate data
-  .dat <- get_dot_data(x, rlang::quos(...))
+  dots <- as.character(match.call(expand.dots = FALSE)$`...`)
+  .dat <- .get_dot_data(x, dots)
 
   if (is.data.frame(x)) {
     # iterate variables of data frame
@@ -222,6 +221,10 @@ zap_unlabelled_helper <- function(x) {
 }
 
 zap_na_tags_helper <- function(x) {
+  if (!requireNamespace("haven", quietly = TRUE)) {
+    stop("Package 'haven' required for this function. Please install it.")
+  }
+
   # check if values has only NA's
   if (sum(is.na(x)) == length(x)) return(x)
   # convert all NA, including tagged NA, into regular NA
